h-review parsing tests

# h-review parsing tests ‐ change logs

The files in this directory where designed to test the parsing of h-review.

## Change log:

- Update JSON output to reflect the parsing rules for src and alt attributes on img elements ‐ 29 April 2020 by Jason Garber
- Update text output to be textContent non-trimmed for implieditem, vcard and item tests ‐ 29 May 2015 by Glenn Jones
- Added missing name property to item test. Also add two missing properties reviewed and rel=licence to vcard test. ‐ 23 May 2015 by Glenn Jones
- Broke old HTML format into small files to aid simpler testing ‐ 21 May 2015 by Glenn Jones
- Updated JSON examples so it always has the rel={} object as well as the items=[] array ‐ 21 November 2013 by Glenn Jones
- Updated encoding issue on e-* ‐ 19 September 2013 by Glenn Jones
- Updated test for h-item ‐ 21 January 2013 by Glenn Jones
- Created ‐ 29 December 2012 by Glenn Jones
- Updated encoding issue on e-* ‐ 19 September 2013 by Glenn Jones

## Contributors:

- Glenn Jones